==> leadlink_open_api-0.0.14.tar.gz: lib/api_product.dart <==
part of leadlinkopenapi;

// 产品类接口
class APIProduct {

  // 根据选中品类获取右侧产品列表
  static void getProductListByCategoryId(int categoryId,bool isOnDisplay,{Function(List<Product> productList) onSucc,Function(String) onFail}) async {

    try {

      var queryCat = QueryBuilder<ProductCategory>(ProductCategory())
      ..whereEqualTo('productCategoryId', categoryId);

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('isOnDisplay', isOnDisplay)
      ..whereMatchesQuery('productCategory',queryCat)
      ..includeObject(['productCategory','accessType']);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<Product>());

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }


  // 获取所有产品列表
  static void getProductListAll(bool isOnDisplay,{Function(List<Product> productList) onSucc,Function(String) onFail}) async {

    try {

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('isOnDisplay', isOnDisplay)
      ..includeObject(['productCategory','accessType']);
      
      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<Product>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取新品产品接口
  static getNewProductList(bool isOnDisplay,{Function(List<Product> productList) onSucc,Function(String) onFail}) async {
    
    try {

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('isNew', true)
      ..whereEqualTo('isOnDisplay', isOnDisplay)
      ..includeObject(['productCategory','accessType']);
      
      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<Product>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取产品详情
  static getProductDetailByProductId(int productId,{Function(Product product) onSucc,Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productId', productId);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(resp.results.length == 0) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      
      Product resProduct = resp.results.first;
      if(onSucc != null) onSucc(resProduct);

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }
}

==> leadlink_open_api-0.0.17.tar.gz: lib/api_product.dart <==
part of leadlinkopenapi;

// 产品类接口
class APIProduct {

  // 根据选中品类获取右侧产品列表
  static void getProductListByCategoryId(int categoryId,{bool isOnDisplay,Function(List<Product> productList) onSucc,Function(String) onFail}) async {

    try {

      var queryCat = QueryBuilder<ProductCategory>(ProductCategory())
      ..whereEqualTo('productCategoryId', categoryId);

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereMatchesQuery('productCategory',queryCat)
      ..includeObject(['productCategory','accessType']);

      if(isOnDisplay != null){
        queryBuider.whereEqualTo('isOnDisplay', isOnDisplay);
      }

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<Product>());

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }


  // 获取所有产品列表
  static void getProductListAll({bool isOnDisplay,Function(List<Product> productList) onSucc,Function(String) onFail}) async {

    try {

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..includeObject(['productCategory','accessType']);
      
      if(isOnDisplay != null) {
        queryBuider.whereEqualTo('isOnDisplay', isOnDisplay);
      }
      
      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<Product>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取新品产品接口
  static getNewProductList(bool isOnDisplay,{Function(List<Product> productList) onSucc,Function(String) onFail}) async {
    
    try {

      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('isNew', true)
      ..whereEqualTo('isOnDisplay', isOnDisplay)
      ..includeObject(['productCategory','accessType']);
      
      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(onSucc != null) onSucc(resp.results.cast<Product>());
    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取产品详情
  static getProductDetailByProductId(int productId,{Function(Product product) onSucc,Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productId', productId);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      if(resp.results.length == 0) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }
      
      Product resProduct = resp.results.first;
      if(onSucc != null) onSucc(resProduct);

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }
}
